==> cplayer-1.0.0.tar.gz: cplayer-1.0.0/cplayer/documentation/help.md <==
# CPlayer

## Table of contents

* [Keymaps](#keymaps)
* [Configuration](#configuration)

### Keymaps

Available keymaps.

| Keymap          | window     | Description                        |
| --------------- | ---------- | ---------------------------------- |
| q               | `all`      | Quit application                   |
| i               | `all`      | go to Information Page             |
| h               | `all`      | go to Home Page                    |
| space           | `playlist` | Play/Pause                         |
| -               | `playlist` | Decrease Volume                    |
| +               | `playlist` | Increase Volume                    |
| l               | `playlist` | Load Playlist                      |
| e               | `playlist` | File Explorer                      |
| d               | `playlist` | Load Directory Path                |
| p               | `playlist` | Previous                           |
| n               | `playlist` | Next                               |
| r               | `playlist` | Restart                            |
| s               | `playlist` | Search                             |
| f               | `playlist` | Filter                             |
| ctrl+s          | `playlist` | Save Playlist                      |
| ctrl+delete     | `playlist` | Delete Song                        |
| A               | `playlist` | Add songs                          |
| ctrl+up         | `playlist` | Up Song                            |
| ctrl+down       | `playlist` | Down Song                          |
| o               | `playlist` | Change playlist order              |
| m               | `playlist` | Mute                               |
| :               | `playlist` | Go to position                     |


### Configuration

The GUI can be configured using the configuration file [~/.config/cplayer/config.yaml](../resources/config/default.yaml).

==> cplayer-1.1.4.tar.gz: cplayer-1.1.4/cplayer/documentation/help.md <==
# CPlayer

## Table of contents

* [Keymaps](#keymaps)
* [Configuration](#configuration)

### Keymaps

Available keymaps.

| Keymap          | window     | Description                        |
| --------------- | ---------- | ---------------------------------- |
| ctrl+q          | `all`      | Quit application                   |
| ?               | `all`      | go to Information Page             |
| h               | `all`      | go to Home Page                    |
| space           | `playlist` | Play/Pause                         |
| -               | `playlist` | Decrease Volume                    |
| +               | `playlist` | Increase Volume                    |
| l               | `playlist` | Load Playlist                      |
| e               | `playlist` | File Explorer                      |
| d               | `playlist` | Load Directory Path                |
| p               | `playlist` | Previous                           |
| n               | `playlist` | Next                               |
| r               | `playlist` | Restart                            |
| /               | `playlist` | Search                             |
| f               | `playlist` | Filter                             |
| ctrl+s          | `playlist` | Save Playlist                      |
| ctrl+delete     | `playlist` | Delete Song                        |
| A               | `playlist` | Add songs                          |
| ctrl+up         | `playlist` | Up Song                            |
| ctrl+down       | `playlist` | Down Song                          |
| o               | `playlist` | Change playlist order              |
| m               | `playlist` | Mute                               |
| :               | `playlist` | Go to position                     |


### Configuration

The GUI can be configured using the configuration file [~/.config/cplayer/config.yaml](../resources/config/default.yaml).
